@@ -1,6 +1,7 @@
 from typing import Optional
 import pandas as pd
 from OctopusAgile import Agile
+from cofybox_dce.octopus_outgoing_workaround import Outgoing
 import warnings
 
 from .abstract import PricingCollector
@@ -11,6 +12,7 @@ class Octopus(PricingCollector):
     country = 'UK'
     supplier = 'Octopus'
     timezone = 'Europe/London'
+    unit = 'p£/kWh'
 
     def __init__(self, region_code: str, **kwargs):
         self.agile = Agile(region_code)
@@ -38,4 +40,13 @@ class Octopus(PricingCollector):
         rates.rename(columns={0: 'value_inc_vat'}, inplace=True)
         rates = rates.tz_convert(self.timezone)
         rates.sort_index(inplace=True)
+        rates['Unit'] = self.unit
         return rates
+
+
+class OctopusOutgoing(Octopus):
+    supplier = 'Octopus_Outgoing'
+
+    def __init__(self, region_code: str, **kwargs):
+        super(OctopusOutgoing, self).__init__(region_code=region_code, **kwargs)
+        self.agile = Outgoing(region_code)
